.. note::
    :class: sphx-glr-download-link-note

    Click :ref:`here <sphx_glr_download_auto_examples_data_plot_scientific.py>` to download the full example code
.. rst-class:: sphx-glr-example-title

.. _sphx_glr_auto_examples_data_plot_scientific.py:


=================
Scientific images
=================

The title of each image indicates the name of the function.





.. rst-class:: sphx-glr-horizontal


    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_001.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_002.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_003.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_004.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_005.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_006.png
            :class: sphx-glr-multi-img

    *

      .. image:: /auto_examples/data/images/sphx_glr_plot_scientific_007.png
            :class: sphx-glr-multi-img





.. code-block:: python

    import matplotlib.pyplot as plt
    import matplotlib

    from skimage import data

    matplotlib.rcParams['font.size'] = 18

    images = ('hubble_deep_field',
              'immunohistochemistry',
              'microaneurysms',
              'moon',
              'retina',
              'shepp_logan_phantom',
              'cell',
              )


    for name in images:
        caller = getattr(data, name)
        image = caller()
        plt.figure()
        plt.title(name)
        if image.ndim == 2:
            plt.imshow(image, cmap=plt.cm.gray)
        else:
            plt.imshow(image)

    plt.show()

**Total running time of the script:** ( 0 minutes  0.323 seconds)


.. _sphx_glr_download_auto_examples_data_plot_scientific.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download

     :download:`Download Python source code: plot_scientific.py <plot_scientific.py>`



  .. container:: sphx-glr-download

     :download:`Download Jupyter notebook: plot_scientific.ipynb <plot_scientific.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
